@@ -45,7 +45,7 @@ class WorklistService(object):
         """
         if self.__worklist != None:
             # perform update
-            return self.__items
+            return self.update_worklist()
 
         wum: WorklistUpdateManagerApi = self.__service_provider.get_service(
             WorklistUpdateManagerApi)
@@ -57,6 +57,10 @@ class WorklistService(object):
         else:
             wlit = wum.logon_and_create_client_worklist(body=update_conf)
 
+        # currently no items in the worklist
+        if wlit == None:
+            return self.__items
+
         self.__iterate(self.__items, wlit)
 
         # remember the current worklist meta data
@@ -102,6 +106,7 @@ class WorklistService(object):
             self.__iterate_updates(updates, inc_updts)
             self.__apply_worklist_updates(
                 inc_updts.source_revision, inc_updts.target_revision, updates)
+        return self.__items
 
     def __iterate_updates(self, updates: List[ClientWorklistItemUpdate], inc: IncWorklistUpdateData):
         """ Consumes the given worklist update iterator and appends all retrieved updates to the provided updates list. 
@@ -133,6 +138,9 @@ class WorklistService(object):
             self.get_worklist()
             return
 
+        #print(f'Applying {len(updates)} updates')
+        #print(updates)
+
         for update in updates:
             self.__apply_worklist_update(update)
 
@@ -147,7 +155,7 @@ class WorklistService(object):
         if update_type == "CHANGED":
             self.__replace_or_add_item(item)
         elif update_type == "ADDED":
-            self.__items += item
+            self.__items += [item]
         elif update_type == "REMOVED":
             self.__remove_item(item)
         elif update_type == "ADDED_OR_CHANGED":
@@ -167,7 +175,7 @@ class WorklistService(object):
                 self.__items[i] = item
                 return
         # not found above, append it
-        self.__items.append(val)
+        self.__items.append(item)
 
     def __remove_item(self, item: ClientWorklistItem):
         """ Removes the given worklist item from self.__items
